{% extends 'base.html' %}
{% load i18n %}
{% load url from future %}

{% block title %}{% trans 'Alarm History' %}{% endblock %}

{% block page_header %}
    <div class="page-header">
      <h2>{% trans 'Alarm History' %}</h2>
    </div>
   <h4>{% trans "Alarm Details" %}</h4>
  <hr class="header_rule">
  <dl>
    <dt>{% trans "Name" %}</dt>
    <dd>{{ alarm.alarm_definition.name|default:_("None") }}</dd>
    {% for metric in alarm.metrics %}
    <dt>{% trans "Metric Name"  %} {{forloop.counter}}</dt>
    <dd>{{ metric.name }}</dd>
    {% endfor %}
  </dl>

{% endblock page_header %}

{% block main %}
    {{ table.render }}
{% endblock %}

