{% extends 'base.html' %}
{% load i18n %}
{% load url from future %}

{% block title %}{% trans 'Alarms' %}{% endblock %}

{% block page_header %}
  {% if service != 'all'%}
    <div class="page-header">
      <h2>{% trans 'Alarms for ' %} {{ service }}</h2>
    </div>
   {% else %}
  {% include "horizon/common/_page_header.html" with title="All Alarms" %}
  {% endif %}
{% endblock page_header %}

{% block main %}
    {{ table.render }}
<style>
.status-icon {
  vertical-align: top;
  margin-right: 2px;
}
</style>
{% endblock %}
