{% extends 'base.html' %}
{% load i18n %}
{% load url from future %}

{% block title %}{% trans 'Alarm Definitions' %}{% endblock %}

{% block page_header %}
{% include "horizon/common/_page_header.html" with title="Alarm Definitions" %}
{% endblock page_header %}

{% block main %}
    {{ table.render }}
{% endblock %}
