{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans 'Monitoring' %}{% endblock %}

{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title="Monitoring" %}
{% endblock page_header %}
{% load url from future %}
{% block main %}
    <div style="padding: 3px;">
      {% for dashboard in dashboards %}
      <a target={{ dashboard.title }} href="/static/grafana/index.html#/dashboard/file/{{ dashboard.fileName }}?api={{api}}" class="btn btn-default btn-sm">
              <span class="glyphicon glyphicon-dashboard"></span>
              {% trans dashboard.title %}
          </a>
      {% endfor %}
    </div>
    {%  include 'monitoring/overview/monitor.html' %}
{% endblock %}
